@@ -1,10 +1,9 @@
-# -*- coding: utf-8 -*-
 from panoramisk.message import Message
 from panoramisk import utils
 import pytest
 
 
-@pytest.yield_fixture
+@pytest.fixture
 def message():
     def _message(data):
         return Message.from_line(data)
